import { NfcPlugin, IsEnabledResult, StartScanSessionOptions, WriteOptions, ShareOptions, PluginListenerHandle } from "./definitions.js";
export declare class WebNfc implements NfcPlugin {
    private scanSessionActive;
    private scanOnce;
    private listeners;
    private ndefReader;
    private nfcSupported;
    constructor();
    private detectNfcSupport;
    isEnabled(): Promise<IsEnabledResult>;
    openSettings(): Promise<void>;
    startScanSession(options?: StartScanSessionOptions): Promise<void>;
    private parseNdefReading;
    private mapRecordTypeToTnf;
    stopScanSession(): Promise<void>;
    write(options: WriteOptions): Promise<void>;
    makeReadOnly(): Promise<void>;
    format(): Promise<void>;
    erase(): Promise<void>;
    share(options: ShareOptions): Promise<void>;
    stopSharing(): Promise<void>;
    addListener(eventName: "nfcStatusChanged" | "tagDetected", listenerFunc: (data: any) => void): Promise<PluginListenerHandle>;
    private removeListener;
    removeAllListeners(): Promise<void>;
    private createCompatibilityError;
}
import { NFCDefinition } from "./definitions";
export declare class WebNFC {
    read(): NFCDefinition;
}
